"use strict";
var yeoman = require("yeoman-generator");
var yosay = require("yosay");
var path = require("path");
var rename = require("gulp-rename");
var fnc = require("../functions.js");

module.exports = yeoman.Base.extend({
    prompting: function () {

        this.log(yosay("FRONTEND: Asp.Net Core + Angular 2,\nBACKEND: Express (Rest Api) + MongoDB"));

        this.log("This generator won't run correctly if you don't have npm, dotnet core or gulp installed!");

        var prompts = [{
            type: "input",
            name: "appNameInput",
            message: "How should your project be called?",
            default: this.appname
        }];

        return this.prompt(prompts).then(function (props) {
            
            props.appNamePascal = fnc.pascalCase(props.appNameInput);
            props.appNameSnake = fnc.snakeCase(props.appNameInput);
            this.props = props;

        }.bind(this));
    },

    writing: function () {
        var self = this;
        this.registerTransformStream(rename(function(path){
            path.basename = path.basename.replace(/(WebApplication392)/g, self.props.appNamePascal);
            path.dirname = path.dirname.replace(/(WebApplication392)/g, self.props.appNamePascal);
        }));
        this.fs.copyTpl(
            this.templatePath(),
            this.destinationPath(), {
                appNamePascal: self.props.appNamePascal,
                appNameSnake: self.props.appNameSnake
            });
    },

    install: function () {
        process.chdir("Web");
        this.spawnCommand("npm", ["install"]).on("close", function () {
            this.log("Web: npm packages installed");
        }.bind(this));

        process.chdir("../Shared");
        this.spawnCommand("npm", ["install"]).on("close", function () {
            this.log("Shared: npm packages installed");
        }.bind(this));

        process.chdir("../RestApi");
        this.spawnCommand("npm", ["install"]).on("close", function () {
            this.log("RestApi: npm packages installed");
        }.bind(this));    
    }
});
